#ifndef _CONFIG_H_
#define _CONFIG_H_


#if OS_LEVEL > 30
#define HAVE_STATE_NOROUTE
#define HAVE_DEVICE_RO
#define HAVE_TREE_H
#define HAVE_PF_ROUTE
#define HAVE_RULE_LABELS
#endif

#if OS_LEVEL > 31
#define HAVE_RULE_NUMBER
#define HAVE_ADDR_WRAP
#define HAVE_RULE_STATES
#define HAVE_RULE_IFNOT
#define HAVE_PROTO_NAMES
#define HAVE_MAX_STATES
#define HAVE_MAX_MSS
#define HAVE_RULE_UGID
#endif

#if OS_LEVEL > 32
#define HAVE_ADDR_MASK
#define HAVE_ADDR_TYPE
#define HAVE_ALTQ
#define HAVE_RULE_TOS
#define HAVE_OP_RRG
#endif

#if OS_LEVEL > 33
#define HAVE_INOUT_COUNT
#define HAVE_TAGS
#define HAVE_RULE_NATPASS
#endif

#if OS_LEVEL > 35
#define HAVE_NEG
#define HAVE_RULESETS
#endif

#if OS_LEVEL > 37
#define HAVE_INOUT_COUNT_RULES
#endif

#endif
